==> ELAN-3_3_0-src.zip: ELAN-3.3.0-src/src/java/mpi/eudico/client/annotator/search/query/viewer/EAFPopupMenu.java <==
/*
 * File:     EAFPopupMenu.java
 * Project:  MPI Linguistic Application
 * Date:     12 December 2007
 *
 * Copyright (C) 2001-2008  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package mpi.eudico.client.annotator.search.query.viewer;

import mpi.eudico.client.im.ImUtil;

import mpi.search.content.query.viewer.AbstractConstraintPanel;
import mpi.search.content.query.viewer.AbstractPopupMenu;

import java.awt.Component;
import java.awt.event.*;

import java.util.Locale;

import javax.swing.JMenuItem;


/**
 * Created on Aug 18, 2004
 * @author Alexander Klassmann
 * @version Aug 18, 2004
 */
public class EAFPopupMenu extends AbstractPopupMenu implements FocusListener {
    /** Holds value of property DOCUMENT ME! */
    final static private Locale[] imLocales = ImUtil.getLanguages();

    /**
     * Creates a new EAFPopupMenu instance
     *
     * @param component DOCUMENT ME!
     * @param constraintPanel DOCUMENT ME!
     */
    public EAFPopupMenu(Component component,
        AbstractConstraintPanel constraintPanel) {
        super(component, constraintPanel);
    }

    /**
     * DOCUMENT ME!
     */
    public void fillMenu() {
        setLabel("Select Language");

        try {
            JMenuItem item;

            for (int i = 0; i < imLocales.length; i++) {
                if ((i == 0) && (imLocales[i] == Locale.getDefault())) {
                    item = new JMenuItem(imLocales[i].getDisplayName() +
                            " (System default)");
                } else {
                    item = new JMenuItem(imLocales[i].getDisplayName());
                }

                add(item);
                item.addActionListener(this);
            }

            component.addFocusListener(this);
        } catch (java.lang.NoSuchMethodError nsme) {
            System.err.println(
                "No input methods found. Probably class ImUtil not in java.lib.ext");
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseClicked(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseExited(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseReleased(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseEntered(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mousePressed(MouseEvent e) {
        if (javax.swing.SwingUtilities.isRightMouseButton(e) ||
                e.isPopupTrigger()) {
            show(component, e.getX(), e.getY());
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        for (int i = 0; i < imLocales.length; i++) {
            if (command.equals(imLocales[i].getDisplayName())) {
                ImUtil.setLanguage(component, imLocales[i]);

                break;
            }
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void focusGained(FocusEvent e) {
        ImUtil.setLanguage(component, component.getLocale());
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void focusLost(FocusEvent e) {
    }
}

==> ELAN-3_8_1-src.zip: ELAN-3.8.1-src/src/java/mpi/eudico/client/annotator/search/query/viewer/EAFPopupMenu.java <==
/*
 * File:     EAFPopupMenu.java
 * Project:  MPI Linguistic Application
 * Date:     25 August 2009
 *
 * Copyright (C) 2001-2009  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package mpi.eudico.client.annotator.search.query.viewer;

import mpi.eudico.client.im.ImUtil;

import mpi.search.content.query.viewer.AbstractConstraintPanel;
import mpi.search.content.query.viewer.AbstractPopupMenu;

import java.awt.Component;
import java.awt.event.*;

import java.util.Locale;

import javax.swing.JMenuItem;


/**
 * Created on Aug 18, 2004
 * @author Alexander Klassmann
 * @version Aug 18, 2004
 */
public class EAFPopupMenu extends AbstractPopupMenu implements FocusListener {
    /** Holds value of property DOCUMENT ME! */
    final static private Locale[] imLocales = ImUtil.getLanguages();

    /**
     * Creates a new EAFPopupMenu instance
     *
     * @param component DOCUMENT ME!
     * @param constraintPanel DOCUMENT ME!
     */
    public EAFPopupMenu(Component component,
        AbstractConstraintPanel constraintPanel) {
        super(component, constraintPanel);
    }

    /**
     * DOCUMENT ME!
     */
    public void fillMenu() {
        setLabel("Select Language");

        try {
            JMenuItem item;

            for (int i = 0; i < imLocales.length; i++) {
                if ((i == 0) && (imLocales[i] == Locale.getDefault())) {
                    item = new JMenuItem(imLocales[i].getDisplayName() +
                            " (System default)");
                } else {
                    item = new JMenuItem(imLocales[i].getDisplayName());
                }

                add(item);
                item.addActionListener(this);
            }

            component.addFocusListener(this);
        } catch (java.lang.NoSuchMethodError nsme) {
            System.err.println(
                "No input methods found. Probably class ImUtil not in java.lib.ext");
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseClicked(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseExited(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseReleased(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mouseEntered(MouseEvent e) {
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void mousePressed(MouseEvent e) {
        if (javax.swing.SwingUtilities.isRightMouseButton(e) ||
                e.isPopupTrigger()) {
            show(component, e.getX(), e.getY());
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        for (int i = 0; i < imLocales.length; i++) {
            if ((i == 0) && (imLocales[i] == Locale.getDefault()) &&
                    (command.indexOf(imLocales[i].getDisplayName()) > -1)) {
                ImUtil.setLanguage(component, imLocales[i]);

                break;
            }

            if (command.equals(imLocales[i].getDisplayName())) {
                ImUtil.setLanguage(component, imLocales[i]);

                break;
            }
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void focusGained(FocusEvent e) {
        ImUtil.setLanguage(component, component.getLocale());
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void focusLost(FocusEvent e) {
    }
}
